//
//  YHJsApi.swift
//  dsbridgedemo
//
//  Created by du on 2018/9/7.
//  Copyright © 2018年 杜文. All rights reserved.
//

import Foundation
import UIKit

typealias JSCallback = (String, Bool)->Void
typealias JSDicCallback = ([String : Any],Bool)->Void

class YHJsApi: NSObject {
    weak var delegate : YHBaseViewController? = nil
}

extension YHJsApi {
    
    //9、跳转资讯列表页
    @objc func goNewsInfomationListUISyn(_ dicData: String) {
        DispatchQueue.main.async {
            if let data = dicData.data(using: .utf8) {
                do {
                    if let jsonObject = try JSONSerialization.jsonObject(with: data, options: []) as? [String: Any] {
                        // 转换成功，jsonObject 是一个字典
                        print("JSON字符串转换为字典成功: \(jsonObject)")
                        /*
                         
                         {
                         id:1,
                         name:"教学升学",
                         hot_num: 1.    //  顶部栏目数量（最新，精品）
                         }
                         */
                        if !jsonObject.isEmpty {
                            let name : String = jsonObject["name"] as? String ?? ""
                            let id : Int = jsonObject["id"] as? Int ?? -1
                            let hot_num : Int = jsonObject["hot_num"] as? Int ?? 0
                            if id > 0 {
                                let vc = YHHomeInfoDetailContainerViewController()
                                vc.customTitle = name
                                vc.isHaveHot = hot_num > 0
                                vc.classifyId = id
                                UIViewController.current?.navigationController?.pushViewController(vc)
                            }
                        } else {
                            printLog("ddddd")
                        }
                    } else {
                        printLog("JSON字符串不是有效的字典格式")
                    }
                } catch {
                    printLog("JSON解析错误: \(error)")
                }
            }
        }
    }
    
    //8、跳转案例分享UI
    @objc func goCaseShareUISyn(_ caseId: String) {
        DispatchQueue.main.async {
            if let id = Int(caseId) {
                let vc = YHResignGuidelinesExampleViewController()
                vc.id = id
                self.delegate?.navigationController?.pushViewController(vc)
            }
        }
    }
    
    //7、跳转 首页-生活 tab
    @objc func goHomeLifeTabSyn(_ fake : Any) {
        DispatchQueue.main.async {
            UIViewController.current?.navigationController?.popToRootViewController(animated: false)
            goTabBarBy(tabType: .home)
            NotificationCenter.default.post(name: YhConstant.YhNotification.didJumpToHomePageLifeTabNotification, object: nil)
        }
    }
    
    //6、跳转H5界面
    @objc func goH5UISyn(_ dicData: String) {
        DispatchQueue.main.async {
            if let data = dicData.data(using: .utf8) {
                do {
                    if let jsonObject = try JSONSerialization.jsonObject(with: data, options: []) as? [String: Any] {
                        // 转换成功，jsonObject 是一个字典
                        print("JSON字符串转换为字典成功: \(jsonObject)")
                        /*
                         url:跳转地址
                         isInformationUrl:1, //1-资讯类型 0-非资讯类型
                         id：1   // 资讯id
                         isFullScreen: 1,// 1-通屏 0-非通屏
                         */
                        
                        if !jsonObject.isEmpty {
                            let url : String = jsonObject["url"] as? String ?? ""
                            let isInformationUrl : Int = jsonObject["isInformationUrl"] as? Int ?? 0
                            let id : Int = jsonObject["id"] as? Int ?? -1
                            let isFullScreen : Int = jsonObject["isFullScreen"] as? Int ?? 1
                            let navTitle : String = jsonObject["navTitle"] as? String ?? ""
                            
                            if isInformationUrl == 1 {
                                //资讯详情
                                let vc = YHHomeWebViewController()
                                vc.id = id
                                vc.url = YHBaseUrlManager.shared.curH5URL() + "articleDetail.html" + "?id=\(id)"
                                self.delegate?.navigationController?.pushViewController(vc)
                            } else {
                                //普通界面
                                if !url.isEmpty {
                                    let vc = YHH5WebViewVC()
                                    vc.url = url
                                    vc.isFullScreenFlag = isFullScreen == 1 ? true : false
                                    vc.navTitle = navTitle
                                    self.delegate?.navigationController?.pushViewController(vc)
                                }
                            }
                        } else {
                            printLog("ddddd")
                        }
                    } else {
                        printLog("JSON字符串不是有效的字典格式")
                    }
                } catch {
                    printLog("JSON解析错误: \(error)")
                }
            }
        }
    }
    
    //5、返回App上一个界面
    @objc func backToAppPreView(_ fake : Any) {
        DispatchQueue.main.async {
            if let delegate = self.delegate as? YHH5WebViewVC {
                delegate.backToAppPreView()
            }
        }
    }
    
    //4、设置app导航栏隐藏、显示
    @objc func setAppNavigation(_ tag : Any) {
        DispatchQueue.main.async {
            let tmp : Bool = tag as? Bool ?? false
            if let delegate = self.delegate as? YHH5WebViewVC {
                delegate.setAppNavigation(tmp)
            }
            
        }
    }
    
    //3、跳转到 办证3 - 赴港时间预约界面
    @objc func gotoAppointCertificateSyn(_ orderID : String) {
        DispatchQueue.main.async {
            if let orderId = Int(orderID) {
                let vc = YHCertificateAppointViewController()
                vc.orderId = orderId
                self.delegate?.navigationController?.pushViewController(vc)
            }
        }
    }
    
    //2、展示图片组
    @objc func showPicsSyn(_ dicData: String) {
        DispatchQueue.main.async {
            if let data = dicData.data(using: .utf8) {
                do {
                    if let jsonObject = try JSONSerialization.jsonObject(with: data, options: []) as? [String: Any] {
                        // 转换成功，jsonObject 是一个字典
                        print("JSON字符串转换为字典成功: \(jsonObject)")
                        
                        if !jsonObject.isEmpty {
                            let curIndex : Int = jsonObject["curIndex"] as? Int ?? -1
                            let arrPics : [String] = jsonObject["pics"] as? [String] ?? []
                            if curIndex > -1,arrPics.count > 0 {
                                YHPictureReviewManager.shared.showNetWorkPicturs(curIndex: curIndex, arrPicturs: arrPics)
                            }
                        } else {
                            printLog("ddddd")
                        }
                    } else {
                        printLog("JSON字符串不是有效的字典格式")
                    }
                } catch {
                    printLog("JSON解析错误: \(error)")
                }
            }
        }
    }
    
    //1、保存图片到本地
    @objc func saveLocalPictureSyn(_ picUrl: String) {
        DispatchQueue.main.async {
            
            if let delegate = self.delegate as? YHH5WebViewVC {
                delegate.saveLocalPictureSyn(picUrl)
            }
        }
    }
}
